searchData={"items":[{"type":"module","title":"Utilx","doc":"","ref":"Utilx.html"},{"type":"module","title":"Utilx.BenchUtils","doc":"Utility for quick and simple benchmarking functions in Elixir.","ref":"Utilx.BenchUtils.html"},{"type":"macro","title":"Utilx.BenchUtils.timeit/2","doc":"Benchmarks the execution time of a piece of code. It should be used only in\nreally simple cases.","ref":"Utilx.BenchUtils.html#timeit/2"},{"type":"macro","title":"Examples - Utilx.BenchUtils.timeit/2","doc":"iex> timeit \"Sleep for a while\", do: :timer.sleep(1000)\n  Executed Sleep for a while in 1.00 seconds","ref":"Utilx.BenchUtils.html#timeit/2-examples"},{"type":"module","title":"Utilx.EctoUtils","doc":"A utility module for handling Ecto queries, with functions to perform common\ntasks like applying a range filter, and executing a series of query operations\nin a pipeline. This module includes Ecto changeset validation functions as well.","ref":"Utilx.EctoUtils.html"},{"type":"function","title":"Utilx.EctoUtils.apply_filters/2","doc":"Applies a series of operations to an Ecto query.","ref":"Utilx.EctoUtils.html#apply_filters/2"},{"type":"function","title":"Parameters - Utilx.EctoUtils.apply_filters/2","doc":"- `query`: The Ecto query to which operations should be applied.\n- `opts`: A list of operations to apply. Each operation is a tuple where the first element is the operation name\n  and the second element is the value to use for that operation.\n\nThe following operations are supported:\n\n- `{:where, filters}`: Adds a `where` clause to the query.\n- `{:select, fields}`: Adds a `select` clause to the query.\n- `{:order_by, criteria}`: Adds an `order_by` clause to the query.\n- `{:limit, criteria}`: Adds a `limit` clause to the query.\n- `{:preload, preload}`: Adds a `preload` clause to the query.","ref":"Utilx.EctoUtils.html#apply_filters/2-parameters"},{"type":"function","title":"Examples - Utilx.EctoUtils.apply_filters/2","doc":"iex> query = from(u in \"users\")\n    iex> EctoUtils.apply_filters(query, where: [age: 18], select: [:id, :email])\n    #Ecto.Query \n\n    iex> query = from(u in \"users\")\n    iex> filters = [\n    ...> {:where, [age: 18]},\n    ...> {:order_by, [desc: :age]},\n    ...> {:select, [:id, :email]},\n    ...> {:limit, 10},\n    ...> {:preload, :posts},\n    ...> {:invalid, \"is ignored from query result\"}\n    ...>]\n    iex> EctoUtils.apply_filters(query, filters)\n    #Ecto.Query","ref":"Utilx.EctoUtils.html#apply_filters/2-examples"},{"type":"function","title":"Utilx.EctoUtils.in_range/3","doc":"Filters a query to only include rows where the specified column's value is within a provided range.","ref":"Utilx.EctoUtils.html#in_range/3"},{"type":"function","title":"Parameters - Utilx.EctoUtils.in_range/3","doc":"- `query`: The Ecto query to filter.\n- `column`: The column on which to apply the range filter.\n- `min..max`: The range of values to filter on.","ref":"Utilx.EctoUtils.html#in_range/3-parameters"},{"type":"function","title":"Examples - Utilx.EctoUtils.in_range/3","doc":"iex> query = from(u in \"users\", select: u.age)\n    iex> EctoUtils.in_range(query, :age, 18..30)\n    #Ecto.Query = ^18 and u0.age","ref":"Utilx.EctoUtils.html#in_range/3-examples"},{"type":"function","title":"Utilx.EctoUtils.validate_url/3","doc":"Validates the structure of a URL field in an Ecto changeset. It does not make it required field.\n\nIf the `field` in the `changeset` is a URL, this function ensures that it has a scheme (defaulting to \"https://\" if\nnone is present), and then checks the URL's structure against a regular expression.\n\nIf the URL's structure is invalid, the `error_message` is attached to the `field` in the `changeset`'s errors.","ref":"Utilx.EctoUtils.html#validate_url/3"},{"type":"function","title":"Parameters - Utilx.EctoUtils.validate_url/3","doc":"- `changeset`: The Ecto changeset containing the URL to validate.\n  - `field`: The key (atom) for the field in the changeset containing the URL.\n  - `error_message`: The error message to attach to the `field` in the `changeset` if the URL is invalid.","ref":"Utilx.EctoUtils.html#validate_url/3-parameters"},{"type":"function","title":"Examples - Utilx.EctoUtils.validate_url/3","doc":"iex> types = %{url: :string}\n    iex> params = %{url: \"https://www.example.com/\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> EctoUtils.validate_url(:url, \"is not a valid url\")\n    #Ecto.Changeset \n\n    iex> types = %{url: :string}\n    iex> params = %{url: \"www.example.com/\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> EctoUtils.validate_url(:url, \"is not a valid url\")\n    #Ecto.Changeset \n\n    iex> types = %{url: :string}\n    iex> params = %{url: nil}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> EctoUtils.validate_url(:url, \"is not a valid url\")\n    #Ecto.Changeset \n\n    iex> types = %{url: :string}\n    iex> params = %{url: \"some@invalid_url\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> EctoUtils.validate_url(:url, \"is not a valid url\")\n    #Ecto.Changeset \n\n    iex> types = %{url: :string}\n    iex> params = %{url: \"Just some random text\"}\n    iex> Ecto.Changeset.cast({%{}, types}, params, Map.keys(types))\n    ...> |> EctoUtils.validate_url(:url, \"is not a valid url\")\n    #Ecto.Changeset","ref":"Utilx.EctoUtils.html#validate_url/3-examples"},{"type":"module","title":"Utilx.EctoUtils.ObjectID","doc":"A Ecto type that facilitates the generation of prefixed base62 encoded UUIDv7\nfor use as primary and foreign keys in Ecto schemas.","ref":"Utilx.EctoUtils.ObjectID.html"},{"type":"module","title":"Examples - Utilx.EctoUtils.ObjectID","doc":"@primary_key {:id, Utilx.EctoUtils.ObjectID, prefix: \"user\", autogenerate: true}\n    @foreign_key_type Utilx.EctoUtils.ObjectID","ref":"Utilx.EctoUtils.ObjectID.html#module-examples"},{"type":"module","title":"Resources - Utilx.EctoUtils.ObjectID","doc":"- https://dev.to/stripe/designing-apis-for-humans-object-ids-3o5a\n  - https://danschultzer.com/posts/prefixed-base62-uuidv7-object-ids-with-ecto","ref":"Utilx.EctoUtils.ObjectID.html#module-resources"},{"type":"type","title":"Utilx.EctoUtils.ObjectID.opts/0","doc":"","ref":"Utilx.EctoUtils.ObjectID.html#t:opts/0"},{"type":"module","title":"Utilx.EncodeUtils.Base62UUID","doc":"A utility module providing functions to encode and decode UUIDs using Base62 encoding.\n\nThe Base62 encoding allows representing UUIDs in a more compact form, reducing their length from 32 to 22 characters.\nThis module supports converting standard UUIDs (as strings) to Base62 encoded UUIDs and vice-versa.","ref":"Utilx.EncodeUtils.Base62UUID.html"},{"type":"function","title":"Utilx.EncodeUtils.Base62UUID.decode/1","doc":"Decodes a Base62 encoded string into a UUID.\n\nThis function is the inverse of `encode/1`. It converts a Base62 encoded string back to its original UUID form.","ref":"Utilx.EncodeUtils.Base62UUID.html#decode/1"},{"type":"function","title":"Examples - Utilx.EncodeUtils.Base62UUID.decode/1","doc":"iex> Base62UUID.decode(\"2FJ5BAFmLzL78YNqBSsS9I\")\n    {:ok, \"49d3793a-2f87-4bcb-aa96-be5892848ae0\"}","ref":"Utilx.EncodeUtils.Base62UUID.html#decode/1-examples"},{"type":"function","title":"Utilx.EncodeUtils.Base62UUID.encode/1","doc":"Encodes a UUID into a Base62 encoded string.","ref":"Utilx.EncodeUtils.Base62UUID.html#encode/1"},{"type":"function","title":"Examples - Utilx.EncodeUtils.Base62UUID.encode/1","doc":"iex> Base62UUID.encode(\"49d3793a-2f87-4bcb-aa96-be5892848ae0\")\n    \"2FJ5BAFmLzL78YNqBSsS9I\"","ref":"Utilx.EncodeUtils.Base62UUID.html#encode/1-examples"},{"type":"module","title":"Utilx.GitUtils","doc":"This module provides utility functions for interacting with Git.","ref":"Utilx.GitUtils.html"},{"type":"function","title":"Utilx.GitUtils.revision_hash/0","doc":"Retrieves the current Git revision hash.","ref":"Utilx.GitUtils.html#revision_hash/0"},{"type":"module","title":"Utilx.NamingUtils","doc":"This module encapsulates common tasks related to processing personal names in\na standardized format. This module treats names as case-insensitive and\nreturns results in a formatted, readable way.","ref":"Utilx.NamingUtils.html"},{"type":"function","title":"Utilx.NamingUtils.capitalize/1","doc":"Capitalizes the first letter of each word in a name.","ref":"Utilx.NamingUtils.html#capitalize/1"},{"type":"function","title":"Parameters - Utilx.NamingUtils.capitalize/1","doc":"- `name`: A string representing a full name, or `nil`.","ref":"Utilx.NamingUtils.html#capitalize/1-parameters"},{"type":"function","title":"Examples - Utilx.NamingUtils.capitalize/1","doc":"iex> NamingUtils.capitalize(nil)\n    \"\"\n\n    iex> NamingUtils.capitalize(\"\")\n    \"\"\n\n    iex> NamingUtils.capitalize(\"john doe\")\n    \"John Doe\"\n\n    iex> NamingUtils.capitalize(\"JOHN DOE\")\n    \"John Doe\"\n\n    iex> NamingUtils.capitalize(\"john nommensen duchac\")\n    \"John Nommensen Duchac\"","ref":"Utilx.NamingUtils.html#capitalize/1-examples"},{"type":"function","title":"Utilx.NamingUtils.extract_first_last_name/1","doc":"Extracts and capitalizes the first and last names from a given name.","ref":"Utilx.NamingUtils.html#extract_first_last_name/1"},{"type":"function","title":"Parameters - Utilx.NamingUtils.extract_first_last_name/1","doc":"- `name`: A string representing a full name, or `nil`.","ref":"Utilx.NamingUtils.html#extract_first_last_name/1-parameters"},{"type":"function","title":"Examples - Utilx.NamingUtils.extract_first_last_name/1","doc":"iex> NamingUtils.extract_first_last_name(nil)\n    \"\"\n\n    iex> NamingUtils.extract_first_last_name(\"\")\n    \"\"\n\n    iex> NamingUtils.extract_first_last_name(\"john\")\n    \"John\"\n\n    iex> NamingUtils.extract_first_last_name(\"john doe smith\")\n    \"John Smith\"","ref":"Utilx.NamingUtils.html#extract_first_last_name/1-examples"},{"type":"function","title":"Utilx.NamingUtils.extract_initials/1","doc":"Extracts the initials from a given name.\n\nThis function takes a name (a string of one or more words), and extracts the\nfirst letter of the first name and the family name.","ref":"Utilx.NamingUtils.html#extract_initials/1"},{"type":"function","title":"Parameters - Utilx.NamingUtils.extract_initials/1","doc":"- `name`: A string representing a full name, or `nil`.","ref":"Utilx.NamingUtils.html#extract_initials/1-parameters"},{"type":"function","title":"Examples - Utilx.NamingUtils.extract_initials/1","doc":"iex> NamingUtils.extract_initials(nil)\n    \"\"\n\n    iex> NamingUtils.extract_initials(\"\")\n    \"\"\n\n    iex> NamingUtils.extract_initials(\"John\")\n    \"J\"\n\n    iex> NamingUtils.extract_initials(\"John Doe\")\n    \"JD\"\n\n    iex> NamingUtils.extract_initials(\"John Nommensen Duchac\")\n    \"JD\"","ref":"Utilx.NamingUtils.html#extract_initials/1-examples"},{"type":"function","title":"Utilx.NamingUtils.shorten_firstname/1","doc":"Shortens the first name to its initial, while preserving the rest of the name.\n\nThis function takes a name (a string of one or more words), and reduces the first name to its initial.\nThe rest of the name is preserved. The initial is followed by a period and a space, and then the rest of the name.","ref":"Utilx.NamingUtils.html#shorten_firstname/1"},{"type":"function","title":"Parameters - Utilx.NamingUtils.shorten_firstname/1","doc":"- `name`: A string representing a full name, or `nil`.","ref":"Utilx.NamingUtils.html#shorten_firstname/1-parameters"},{"type":"function","title":"Examples - Utilx.NamingUtils.shorten_firstname/1","doc":"iex> NamingUtils.shorten_firstname(nil)\n    \"\"\n\n    iex> NamingUtils.shorten_firstname(\"\")\n    \"\"\n\n    iex> NamingUtils.shorten_firstname(\"John\")\n    \"J.\"\n\n    iex> NamingUtils.shorten_firstname(\"john\")\n    \"J.\"\n\n    iex> NamingUtils.shorten_firstname(\"John Doe\")\n    \"J. Doe\"\n\n    iex> NamingUtils.shorten_firstname(\"john doe\")\n    \"J. Doe\"\n\n    iex> NamingUtils.shorten_firstname(\"john doe jr\")\n    \"J. Doe Jr\"","ref":"Utilx.NamingUtils.html#shorten_firstname/1-examples"}],"content_type":"text/markdown"}